@@ -10,6 +10,7 @@ from base64 import b64encode, b64decode
 from tiddlyweb.serializer import TiddlerFormatError
 from tiddlyweb.serializations import SerializationInterface
 from tiddlyweb.model.policy import Policy
+from tiddlyweb.util import binary_tiddler
 
 
 class Serialization(SerializationInterface):
@@ -23,22 +24,32 @@ class Serialization(SerializationInterface):
         """
         Return a linefeed separated list of recipe names.
         """
-        return "\n".join([recipe.name for recipe in recipes])
+        return ('%s\n' % recipe.name for recipe in recipes)
 
     def list_bags(self, bags):
         """
         Return a linefeed separated list of recipe names.
         """
-        return "\n".join([bag.name for bag in bags])
+        return ('%s\n' % bag.name for bag in bags)
+
+    def list_tiddlers(self, tiddlers):
+        """
+        List the tiddlers as text.
+        """
+        if hasattr(tiddlers, 'is_revisions') and tiddlers.is_revisions:
+            for tiddler in tiddlers:
+                yield "%s:%s\n" % (tiddler.title, tiddler.revision)
+        else:
+            for tiddler in tiddlers:
+                yield "%s\n" % tiddler.title
+        return
 
     def recipe_as(self, recipe):
         """
         Recipe as text.
         """
-        policy = recipe.policy
-        policy_dict = {}
-        for key in Policy.attributes:
-            policy_dict[key] = getattr(policy, key)
+        policy_dict = dict([(key, getattr(recipe.policy, key)) for
+                key in Policy.attributes])
         lines = ['desc: %s' % recipe.desc, 'policy: %s' %
                 simplejson.dumps(policy_dict), '']
 
@@ -46,10 +57,12 @@ class Serialization(SerializationInterface):
             line = ''
             if not isinstance(bag, basestring):
                 bag = bag.name
-            line += '/bags/%s/tiddlers' % urllib.quote(bag.encode('utf-8'), safe='')
+            line += '/bags/%s/tiddlers' % urllib.quote(
+                    bag.encode('utf-8'), safe='')
             if filter_string:
                 line += '?%s' % filter_string
             lines.append(line)
+
         return "\n".join(lines)
 
     def as_recipe(self, recipe, input_string):
@@ -85,26 +98,13 @@ class Serialization(SerializationInterface):
         recipe.set_recipe(recipe_lines)
         return recipe
 
-    def list_tiddlers(self, bag):
-        """
-        List the tiddlers in a bag as text.
-        """
-        if bag.revbag:
-            return "\n".join(
-                    ["%s:%s" % (tiddler.title, tiddler.revision)
-                        for tiddler in bag.gen_tiddlers()])
-        else:
-            return "\n".join([
-                tiddler.title for tiddler in bag.gen_tiddlers()])
-
     def tiddler_as(self, tiddler):
         """
         Represent a tiddler as a text string: headers, blank line, text.
         """
         if not tiddler.text:
             tiddler.text = ''
-        if (tiddler.type and tiddler.type != 'None' and not
-                tiddler.type.startswith('text/')):
+        if binary_tiddler(tiddler):
             tiddler.text = b64encode(tiddler.text)
         return ('modifier: %s\ncreated: %s\nmodified: %s\ntype: '
                 '%s\ntags: %s%s\n%s\n' %
@@ -146,7 +146,6 @@ class Serialization(SerializationInterface):
             raise TiddlerFormatError('bad headers in tiddler: %s, %s' %
                     (tiddler.title, exc))
 
-
         # In some strange situations tiddler.tags will not
         # be a string here, so will still have its default
         # value of [], which we want to keep.
@@ -156,8 +155,7 @@ class Serialization(SerializationInterface):
                 tiddler.tags = self.as_tags(tag_string)
 
         # If this is a binary tiddler, clean up.
-        if (tiddler.type and tiddler.type != 'None' and not
-                tiddler.type.startswith('text/')):
+        if binary_tiddler(tiddler):
             tiddler.text = b64decode(tiddler.text.lstrip().rstrip())
 
         return tiddler
