@@ -107,17 +107,15 @@ def list_recipes(environ, start_response):
     store = environ['tiddlyweb.store']
     serialize_type, mime_type = web.get_serialize_type(environ)
     serializer = Serializer(serialize_type, environ)
-    return list_entities(environ, start_response, mime_type, store.list_recipes,
-            serializer.list_recipes)
+    return list_entities(environ, start_response, mime_type,
+            store.list_recipes, serializer.list_recipes)
 
 
 def put(environ, start_response):
     """
     Put a new recipe to the server.
     """
-    recipe_name = environ['wsgiorg.routing_args'][1]['recipe_name']
-    recipe_name = urllib.unquote(recipe_name)
-    recipe_name = unicode(recipe_name, 'utf-8')
+    recipe_name = web.get_route_value(environ, 'recipe_name')
     recipe_name = web.handle_extension(environ, recipe_name)
 
     recipe = Recipe(recipe_name)
@@ -175,9 +173,7 @@ def _determine_recipe(environ):
     Interpret URL information to determine the target
     recipe and then get it from the store.
     """
-    recipe_name = environ['wsgiorg.routing_args'][1]['recipe_name']
-    recipe_name = urllib.unquote(recipe_name)
-    recipe_name = unicode(recipe_name, 'utf-8')
+    recipe_name = web.get_route_value(environ, 'recipe_name')
     recipe_name = web.handle_extension(environ, recipe_name)
     recipe = Recipe(recipe_name)
 
