@@ -13,12 +13,13 @@ from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.policy import PermissionsError
 from tiddlyweb.model.recipe import Recipe
 from tiddlyweb.model.tiddler import Tiddler, current_timestring
-from tiddlyweb.store import \
-        NoTiddlerError, NoBagError, NoRecipeError, StoreMethodNotImplemented
-from tiddlyweb.serializer import Serializer, TiddlerFormatError, NoSerializationError
+from tiddlyweb.store import (NoTiddlerError, NoBagError, NoRecipeError,
+        StoreMethodNotImplemented)
+from tiddlyweb.serializer import (Serializer, TiddlerFormatError,
+        NoSerializationError)
 from tiddlyweb.util import sha, pseudo_binary
-from tiddlyweb.web.http import \
-        HTTP404, HTTP415, HTTP412, HTTP409, HTTP400, HTTP304
+from tiddlyweb.web.http import (HTTP404, HTTP415, HTTP412, HTTP409,
+        HTTP400, HTTP304)
 from tiddlyweb import control
 from tiddlyweb.web import util as web
 from tiddlyweb.web.sendtiddlers import send_tiddlers
@@ -123,14 +124,13 @@ def _determine_tiddler(environ, bag_finder):
     This can be complicated because of the mechanics
     of recipes and bags.
     """
-    tiddler_name = environ['wsgiorg.routing_args'][1]['tiddler_name']
-    tiddler_name = urllib.unquote(tiddler_name)
-    tiddler_name = unicode(tiddler_name, 'utf-8')
-    revision = environ['wsgiorg.routing_args'][1].get('revision', None)
-    if revision:
+    tiddler_name = web.get_route_value(environ, 'tiddler_name')
+    try:
+        revision = web.get_route_value(environ, 'revision')
         revision = web.handle_extension(environ, revision)
-    else:
+    except KeyError:
         tiddler_name = web.handle_extension(environ, tiddler_name)
+        revision = None
 
     tiddler = Tiddler(tiddler_name)
     if revision:
@@ -174,10 +174,8 @@ def _determine_tiddler(environ, bag_finder):
             else:
                 tiddler.text = content
 
-    recipe_name = environ['wsgiorg.routing_args'][1].get('recipe_name', None)
-    if recipe_name:
-        recipe_name = urllib.unquote(recipe_name)
-        recipe_name = unicode(recipe_name, 'utf-8')
+    try:
+        recipe_name = web.get_route_value(environ, 'recipe_name')
         recipe = Recipe(recipe_name)
         try:
             store = environ['tiddlyweb.store']
@@ -192,10 +190,8 @@ def _determine_tiddler(environ, bag_finder):
             raise HTTP404('%s not found via bag, %s' % (tiddler.title, exc))
 
         bag_name = bag.name
-    else:
-        bag_name = environ['wsgiorg.routing_args'][1]['bag_name']
-        bag_name = urllib.unquote(bag_name)
-        bag_name = unicode(bag_name, 'utf-8')
+    except KeyError:
+        bag_name = web.get_route_value(environ, 'bag_name')
 
     tiddler.bag = bag_name
     return tiddler
@@ -404,7 +400,8 @@ def _validate_tiddler_headers(environ, tiddler):
         incoming_etag = environ.get('HTTP_IF_MATCH', None)
         logging.debug('attempting to validate incoming etag(PUT):'
             '%s against %s', incoming_etag, tiddler_etag)
-        if incoming_etag and not _etag_write_match(incoming_etag, tiddler_etag):
+        if incoming_etag and not _etag_write_match(incoming_etag,
+                tiddler_etag):
             raise HTTP412('Provided ETag does not match. '
                 'Server content probably newer.')
     etag = ('Etag', '%s' % tiddler_etag)
