@@ -65,8 +65,10 @@ def start_cherrypy(config):
     app = load_app()
     server = wsgiserver.CherryPyWSGIServer((hostname, port), app)
     try:
-        logging.debug('starting cherrypy at %s://%s:%s', scheme, hostname, port)
-        std_error_message("Starting CherryPy at %s://%s:%s" % (scheme, hostname, port))
+        logging.debug('starting cherrypy at %s://%s:%s',
+                scheme, hostname, port)
+        std_error_message("Starting CherryPy at %s://%s:%s"
+                % (scheme, hostname, port))
         server.start()
     except KeyboardInterrupt:
         server.stop()
